@@ -61,18 +61,17 @@ PRODUCTS = {
     "1/73": ("(KPC7) Controller - 7 Button", "Keypad"),
     "1/74": ("(KPLR7) Keypad Load Relay - 7 Button", "Keypad"),
     "1/75": ("(KPLD7) Keypad Load Dimmer - 7 Button", "Keypad"),
-    "HAI/1": ("35A00-1 600W Dimming Switch", "Switch"),
-    "HAI/2": ("35A00-2 1000W Dimming Switch", "Switch"),
-    "HAI/16": ("35A00-3 600W Non-Dimming Switch", "Switch"),
-    "HAI/17": ("35A00-4 1000W Non-Dimming Switch", "Switch"),
-    "HAI/18": ("40A00-1 15A Relay Switch", "Switch"),
-    "HAI/3": ("55A00-1 1000W Dimming Switch", "Switch"),
-    "HAI/4": ("55A00-2 1500W Dimming Switch", "Switch"),
-    "HAI/5": ("55A00-3 2400W Dimming Switch", "Switch"),
-    "HAI/32": ("59A00-1 300W Lamp Module", "Module"),
-    "HAI/48": ("60A00-1 15A Appliance Module", "Module"),
-    "HAI/80": ("38A00-1 6-Button Room Controller", "Keypad"),
-    "HAI/96": ('38A00-2 8-Button House Controller"', "Keypad"),
+    "2/32": ("(VHC) Vacuum Handle Controller", "VHC"),
+    "2/33": ("(VPM) Vacuum Power Module", "VPM"),
+    "2/35": ("(VIM) Vacuum Input Module", "Input"),
+    "2/36": ("(DSM) Doorbell Sense Module", "Input"),
+    "2/37": ("(TSM) Telephone Sense Module", "Input"),
+    "3/1": ("LM01 Lamp Module - Basic", "Switch"),
+    "3/5": ("AM01 Appliance Module - Basic", "Switch"),
+    "3/7": ("FXR01 Fixture, Relay", "Switch"),
+    "3/8": ("OUT01 Switched Receptacle Outlet", "Switch"),
+    "3/29": ("SW7 Dimmer switch", "Switch"),
+    "3/30": ("SPIM01 Serial Powerline Interface Module", "Switch"),
     "4/1": ("UML Lamp Module", "Module"),
     "4/5": ("UMA Appliance Module", "Module"),
     "4/7": ("UFR Fixture Relay ", "URD Receptacle"),
@@ -94,15 +93,20 @@ PRODUCTS = {
     "4/44": ("USM1R", "Switch"),
     "4/45": ("USM2R", "Switch"),
     "4/40": ("UMI-32 3-Input ", "2-Output Module"),
-    "WMT/88": ("CLSW-01 Classic series single dimmer wall switch", "Switch"),
-    "WMT/89": ("CL6-01 Classic series wall mount 6 button", "Keypad controller"),
     "4/201": ("Lamp Module (UML-E)", "Module"),
     "4/205": ("Appliance Module (UMA-E)", "Module"),
     "4/222": ("Retail Dimming Switch (RS101)", "Switch"),
     "4/240": ("Retail I", "O 32 Module"),
-    "MD/32": ("(VHC) Vacuum Handle Controller", "VHC"),
-    "MD/33": ("(VPM) Vacuum Power Module", "VPM"),
-    "MD/35": ("(VIM) Vacuum Input Module", "Input"),
-    "MD/36": ("(DSM) Doorbell Sense Module", "Input"),
-    "MD/37": ("(TSM) Telephone Sense Module", "Input"),
+    "5/1": ("35A00-1 600W Dimming Switch", "Switch"),
+    "5/2": ("35A00-2 1000W Dimming Switch", "Switch"),
+    "5/16": ("35A00-3 600W Non-Dimming Switch", "Switch"),
+    "5/17": ("35A00-4 1000W Non-Dimming Switch", "Switch"),
+    "5/18": ("40A00-1 15A Relay Switch", "Switch"),
+    "5/3": ("55A00-1 1000W Dimming Switch", "Switch"),
+    "5/4": ("55A00-2 1500W Dimming Switch", "Switch"),
+    "5/5": ("55A00-3 2400W Dimming Switch", "Switch"),
+    "5/32": ("59A00-1 300W Lamp Module", "Module"),
+    "5/48": ("60A00-1 15A Appliance Module", "Module"),
+    "5/80": ("38A00-1 6-Button Room Controller", "Keypad"),
+    "5/96": ('38A00-2 8-Button House Controller"', "Keypad"),
 }
